@@ -2,151 +2,11 @@ import time
 from typing import Tuple, Dict, Any
 from web3 import HTTPProvider, Web3
 from eth_utils.abi import function_abi_to_4byte_selector, collapse_if_tuple
+from actions_lib.actions.consts import CHAIN_ID_MAPPING, TOKEN_MAPPING
 from actions_lib.actions.type import Action, ActionData
-from actions_lib.actions.user.user import decrease_token_amount, increase_token_amount
 from actions_lib.utils.contact_tool import get_contact_address
 from cdp import *
 
-# Constants
-TOKEN_MAPPING = {
-    "ethereum": {
-        "eth": {
-            "address": None,
-            "decimal": 18
-        },
-        # testnet
-        "usdc": {
-            "address": "0xd10519Aa03FE7Ffb95189B52B74F94Fb33E2C88a",
-            "decimal": 6
-        },
-        # mainnet
-        # "usdc": {
-        #     "address": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
-        #     "decimal": 6
-        # },
-        "usdt": {
-            "address": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
-            "decimal": 6
-        },
-        "bnb": {
-            "address": "0xB8c77482e45F1F44dE1745F52C74426C631bDD52",
-            "decimal": 18
-        },
-        "dai": {
-            "address": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
-            "decimal": 18
-        },
-        "uni": {
-            "address": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
-            "decimal": 18
-        },
-        "btc": {
-            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
-            "decimal": 8
-        },
-        "wbtc": {
-            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
-            "decimal": 8
-        },
-        "cbbtc": {
-            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
-            "decimal": 8
-        },
-        "ens": {
-            "address": "0xC18360217D8F7Ab5e7c516566761Ea12Ce7F9D72",
-            "decimal": 18
-        }
-    },
-    "eth": {
-        "eth": {
-            "address": None,
-            "decimal": 18
-        },
-        # testnet
-        "usdc": {
-            "address": "0xd10519Aa03FE7Ffb95189B52B74F94Fb33E2C88a",
-            "decimal": 6
-        },
-        # mainnet
-        # "usdc": {
-        #     "address": "0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48",
-        #     "decimal": 6
-        # },
-        "usdt": {
-            "address": "0xdAC17F958D2ee523a2206206994597C13D831ec7",
-            "decimal": 6
-        },
-        "bnb": {
-            "address": "0xB8c77482e45F1F44dE1745F52C74426C631bDD52",
-            "decimal": 18
-        },
-        "dai": {
-            "address": "0x6B175474E89094C44Da98b954EedeAC495271d0F",
-            "decimal": 18
-        },
-        "uni": {
-            "address": "0x1f9840a85d5aF5bf1D1762F925BDADdC4201F984",
-            "decimal": 18
-        },
-        "btc": {
-            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
-            "decimal": 8
-        },
-        "wbtc": {
-            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
-            "decimal": 8
-        },
-        "cbbtc": {
-            "address": "0x2260FAC5E5542a773Aa44fBCfeDf7C193bc2C599",
-            "decimal": 8
-        },
-        "ens": {
-            "address": "0xC18360217D8F7Ab5e7c516566761Ea12Ce7F9D72",
-            "decimal": 18
-        }
-    },
-    "base": {
-        "eth": {
-            "address": None,
-            "decimal": 18
-        },
-        # testnet
-        "usdc": {
-            "address": "0x45b58118a5374dccf7fd6f3f66c66278ab7473d9",
-            "decimal": 6
-        },
-        # mainnet
-        # "usdc": {
-        #     "address": "0x833589fCD6eDb6E08f4c7C32D4f71b54bdA02913",
-        #     "decimal": 6
-        # },
-        "btc": {
-            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
-            "decimal": 8
-        },
-        "wbtc": {
-            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
-            "decimal": 8
-        },
-        "cbbtc": {
-            "address": "0xcbB7C0000aB88B473b1f5aFd9ef808440eed33Bf",
-            "decimal": 8
-        }
-    },
-}
-
-CHAIN_ID_MAPPING = {
-    'base': '0x14a34',
-    'ethereum': '0xaa36a7',
-    'eth': '0xaa36a7'
-}
-
-# CHAIN_ID_MAPPING = {
-#     'base': '0x2105',
-#     'ethereum': '0x1',
-#     'eth': '0x1'
-# }
-
 # ABIs
 ALLOWANCE_ABI = """[{"constant":true,"inputs":[{"name":"_owner","type":"address"},{"name":"_spender","type":"address"}],"name":"allowance","outputs":[{"name":"","type":"uint256"}],"payable":false,"stateMutability":"view","type":"function"}]"""
 
@@ -180,31 +40,37 @@ def record_transaction(redis_client, user_id: str, chain: str, tx_hash: str) ->
     redis_client.rpush(key, tx_hash)
     print(f"Recorded transaction {tx_hash} on {chain} for user {user_id}")
 
-def mpc_transfer(default_address: WalletAddress, destination, chain_raw, token_raw, token_address, amount):
+def mpc_transfer(mpc_address: WalletAddress, destination, chain_raw, token_raw, token_address, amount):
     tx_hash = None
     try:
         if chain_raw == 'base' and token_raw == 'usdc':
-            transfer = default_address.transfer(amount, 'usdc', destination, gasless=True)
+            transfer = mpc_address.transfer(amount, 'usdc', destination, gasless=True)
             try:
                 transfer.wait()
             except Exception as e:
                 print(f"Transfer error: {e}", flush=True)
 
+            timeout = 10  
+            start_time = time.time()
             while str(transfer.status) not in ['complete','failed']:
-                print(f"Waiting for transaction status: {transfer.status}")
+                if time.time() - start_time > timeout:
+                    print("Timeout: Transaction status check exceeded 10 seconds.", flush=True)
+                    break
+                print(f"Waiting for transaction status: {transfer.status}", flush=True)
                 transfer.reload()
                 tx_hash = str(transfer.transaction_hash)
                 time.sleep(1)
+
             if str(transfer.status) == 'complete':
                 status = 200
                 transfer_status = 1
-                print(f"Transfer complete: {transfer.transaction_hash}")
-                print(f"Transfer successfully landed on-chain: {transfer.transaction_link}")
+                print(f"Transfer complete: {transfer.transaction_hash}", flush=True)
+                print(f"Transfer successfully landed on-chain: {transfer.transaction_link}", flush=True)
             else:
                 print(f"Error: {transfer.status}")
                 status = 500
                 transfer_status = 0
-                print(f"Transfer failed on-chain: {transfer.transaction_link}")
+                print(f"Transfer failed on-chain: {transfer.transaction_link}", flush=True)
 
             info = {
                 "content": generate_tx_link_content(str(transfer.status), transfer.transaction_link),
@@ -308,11 +174,11 @@ def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amou
     
     if token_raw == 'usdc' and chain_raw == 'base':
         amount_to_transfer = convert_to_wei(float(amount), chain_raw, token_raw)
-        try:
-            decrease_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
-        except Exception as e:
-            print(f"Exception occurred: {e}", flush=True)
-            return {'result': {"content": f"{e}", "code": 500}, 'action': None, 'next_action': None}
+        # try:
+        #     decrease_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
+        # except Exception as e:
+        #     print(f"Exception occurred: {e}", flush=True)
+        #     return {'result': {"content": f"{e}", "code": 500}, 'action': None, 'next_action': None}
         try:
             code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
             if code != 200:
@@ -323,11 +189,11 @@ def handle_auto_transfer(w3: Web3, eth_w3, mpc_address, executor, receiver, amou
 
             print(f"to: {to}, executor: {executor}", flush=True)
             info = mpc_transfer(mpc_address, to, chain_raw, token_raw, token_address, amount)
-            if info['code'] != 200:
-                increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
+            # if info['code'] != 200:
+            #     increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
             return {'result': info, 'action': None, 'next_action': None}
         except Exception as e:
-            increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
+            # increase_token_amount(redis_client, executor, chain_raw, token_raw, amount_to_transfer)
             return handle_transaction_error(e, control_contract, w3)
     else:
         token = token_raw.upper()
